
# Slot: id




URI: [biolink:pairwise_interaction_association_id](https://w3id.org/biolink/vocab/pairwise_interaction_association_id)

## Domain and Range

[PairwiseInteractionAssociation](PairwiseInteractionAssociation.md) ->  <sub>REQ</sub> [IdentifierType](IdentifierType.md)

## Parents

 *  is_a: [id](association_id.md)

## Children


## Used by

 * [PairwiseInteractionAssociation](PairwiseInteractionAssociation.md)
